# Sphinx Documentation

A `sphinx-quickstart` command has been run and autosummary templates have been added to your system. The `source/conf.py` file has been modified to enable the use of several extensions, and help in configuring the documentation for your project.

## Initial setup

* Replace `PROJ` with the name of your project for the __version__ import
* Replace the string `<PROJ_NAME>` with your projects name
* Replace the string `<AUTHORS>` with your author list
